﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.DataPreprocessing.Filter;
using System.Collections.Generic;
using System;
using System.Linq;
namespace HeuristicLab.DataPreprocessing {
  public class FilterLogic : IFilterLogic {

    private ITransactionalPreprocessingData preprocessingData;

    public FilterLogic(ITransactionalPreprocessingData preprocessingData) {
      this.preprocessingData = preprocessingData;
    }

    public bool[] Preview(IList<IFilter> filters)
    {
       IList<IFilter> activeFilters = filters.Where(f => f.Active && f.ConstraintData != null).ToList<IFilter>();

       if (activeFilters.Count == 0) { 
        return new bool[preprocessingData.Rows];
       }

       bool[] result = Enumerable.Repeat<bool>(true, preprocessingData.Rows).ToArray();

       foreach (IFilter filter in activeFilters)
       {
            bool[] filterResult = filter.Check();

            for(int row = 0; row < result.Length; ++row) {
                result[row] = result[row] && filterResult[row];
            }
        }

        return result;
    }

    public void Apply(IList<IFilter> filters)
    {
        bool[] results = Preview(filters);

        preprocessingData.InTransaction(() =>
        {
          for (int row = (results.Length - 1); row >= 0; --row)
          {
            if (results[row])
            {
              preprocessingData.DeleteRow(row);
            }
          }
        });
     }


    public IPreprocessingData PreprocessingData
    {
      get { return preprocessingData; }
    }
  }
}
